********************************************************************************
*Stata Codes for the Paper on Associations Between Depression and Anxiety with Incident Diabetes - Data from Kerala Diabetes Prevention Program 
********************************************************************************
*Aim 3
use file "KDPP data 1007_wide_CCA.dta"
*Descriptives
by diabetes, sort: summ age0
by diabetes, sort: tab sex0
by diabetes, sort: tab maritalstatus_dich0
by diabetes, sort: summ schoolyears0
by diabetes, sort: tab fhdiab0
by diabetes, sort: tab alcohol0
by diabetes, sort: tab tobacco0
by diabetes, sort: tab fruitvegcat0
by diabetes, sort: tab pa_leisure0
by diabetes, sort: tab short_sleep0
by diabetes, sort: tab cenobesity0
by diabetes, sort: tab hyp0
by diabetes, sort: summ friedldlmgdl0
by diabetes, sort: tab PHQ9_dich0
by diabetes, sort: tab gads_dich0

use file "KDPP data 1007_long_CCA.dta"
*GEE - Univariate analysis 
xtset cluster
xtgee diabetes age, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes b1.sex, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes b2.maritalstatus_dich, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes schoolyears, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes i.fhdiab, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes i.alcohol, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes i.tobacco, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes b1.fruitvegcat, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes i.pa_leisure, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes i.short_sleep, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes i.cenobesity, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes i.hyp, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes friedldlmgdl, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes i.PHQ9_dich, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
xtgee diabetes i.gads_dich, vce(robust) family(binomial) link(logit) corr(exchangeable) eform

*GEE - Multivariable analysis
**PHQ-9
**Model selection, GOF, and correlation between observations of diabetes incidence over time 
xtset cluster 
xtgee diabetes i.PHQ9_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
qic diabetes PHQ9_dich arms age sex maritalstatus_dich schoolyears fhdiab, family(binomial) link(logit) corr(exchangeable) eform
estat wcorrelation

xtgee diabetes i.PHQ9_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab i.alcohol i.tobacco b1.fruitvegcat i.pa_leisure i.short_sleep, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
qic diabetes PHQ9_dich arms age sex maritalstatus_dich schoolyears fhdiab alcohol tobacco fruitvegcat pa_leisure short_sleep, family(binomial) link(logit) corr(exchangeable) eform

xtgee diabetes i.PHQ9_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab i.alcohol i.tobacco b1.fruitvegcat i.pa_leisure i.short_sleep i.cenobesity i.hyp friedldlmgdl, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
qic diabetes PHQ9_dich arms age sex maritalstatus_dich schoolyears fhdiab alcohol tobacco fruitvegcat pa_leisure short_sleep cenobesity hyp friedldlmgdl, family(binomial) link(logit) corr(exchangeable) eform 

**GAD-7
**Model selection, GOF, and correlation between observations of diabetes incidence over time  
xtset cluster 
xtgee diabetes i.gads_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
qic diabetes gads_dich arms age sex maritalstatus_dich schoolyears fhdiab, family(binomial) link(logit) corr(exchangeable) eform

xtgee diabetes i.gads_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab i.alcohol i.tobacco b1.fruitvegcat i.pa_leisure i.short_sleep, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
qic diabetes gads_dich arms age sex maritalstatus_dich schoolyears fhdiab alcohol tobacco fruitvegcat pa_leisure short_sleep, family(binomial) link(logit) corr(exchangeable) eform

xtgee diabetes i.gads_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab i.alcohol i.tobacco b1.fruitvegcat i.pa_leisure i.short_sleep i.cenobesity i.hyp friedldlmgdl, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
qic diabetes gads_dich arms age sex maritalstatus_dich schoolyears fhdiab alcohol tobacco fruitvegcat pa_leisure short_sleep cenobesity hyp friedldlmgdl, family(binomial) link(logit) corr(exchangeable) eform 

********************************************************************************
*Multiple imputation 
********************************************************************************
*Use file
use file "KDPP data 1007_long_CCA.dta"

*Data missingness
mdesc tobacco short_sleep sex schoolyears pa_leisure maritalstatus_dich hyp gads_dich fruitvegcat friedldlmgdl fhdiab cenobesity alcohol age PHQ9_dich if wave==0
mdesc diabetes

*Set-up the data for multiple imputation
mi set mlong 

*Register the variables that require imputation 
mi register imputed diabetes gads_dich cenobesity PHQ9_dich 

*Impute the missing data using chained equations
mi impute chained (logit) diabetes (logit) gads_dich (logit) cenobesity (logit) PHQ9_dich=age sex tobacco short_sleep schoolyears pa_leisure maritalstatus_dich hyp fruitvegcat friedldlmgdl fhdiab alcohol, add(10) 
  
*Save file
save file "KDPP data 1007_long_MI.dta"

use file "KDPP data 1007_long_MI.dta"
*Multiple Imputation GGE analysis 
**PHQ-9
mi xtset cluster
mi estimate: xtgee diabetes i.PHQ9_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
mi estimate: xtgee diabetes i.PHQ9_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab i.alcohol i.tobacco b1.fruitvegcat i.pa_leisure i.short_sleep, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
mi estimate: xtgee diabetes i.PHQ9_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab i.alcohol i.tobacco b1.fruitvegcat i.pa_leisure i.short_sleep i.cenobesity i.hyp friedldlmgdl, vce(robust) family(binomial) link(logit) corr(exchangeable) eform

**GAD-7
mi xtset cluster
mi estimate: xtgee diabetes i.gads_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
mi estimate: xtgee diabetes i.gads_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab i.alcohol i.tobacco b1.fruitvegcat i.pa_leisure i.short_sleep, vce(robust) family(binomial) link(logit) corr(exchangeable) eform
mi estimate: xtgee diabetes i.gads_dich i.arms age b1.sex b2.maritalstatus_dich schoolyears i.fhdiab i.alcohol i.tobacco b1.fruitvegcat i.pa_leisure i.short_sleep i.cenobesity i.hyp friedldlmgdl, vce(robust) family(binomial) link(logit) corr(exchangeable) eform

********************************************************************************
*Participation bias
********************************************************************************
use file "KDPP data 1007_wide_CCA.dta"

by followup, sort: summ age0
by followup, sort: tab sex0
by followup, sort: tab maritalstatus_dich0
by followup, sort: summ schoolyears0
by followup, sort: tab fhdiab0
by followup, sort: tab alcohol0
by followup, sort: tab tobacco0
by followup, sort: tab fruitvegcat0
by followup, sort: tab pa_leisure0
by followup, sort: tab short_sleep0
by followup, sort: tab cenobesity0
by followup, sort: tab hyp0
by followup, sort: summ friedldlmgdl0
by followup, sort: tab PHQ9_dich0
by followup, sort: tab gads_dich0
